from setuptools import setup, find_packages

setup(
    name='colorful_logging',
    version='0.2',
    packages=find_packages(),
    install_requires=[],
    url='https://github.com/zamoosh/colorful_logging',
    author='zamoosh',
    author_email='moyi.pary@gmail.com',
    description='A library to print colorful',
    license='MIT',
)
